==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/ad/ChainEffectiveResultDetailWithCampaignAndShopAndDate.java <==
package eleme.openapi.sdk.api.entity.ad;

public class ChainEffectiveResultDetailWithCampaignAndShopAndDate{

    /**
     * 店铺id
     */
    private Long shopId;
    public Long getShopId() {
        return shopId;
    }
    public void setShopId(Long shopId) {
        this.shopId = shopId;
    }
    
    /**
     * 计划id
     */
    private Long campaignId;
    public Long getCampaignId() {
        return campaignId;
    }
    public void setCampaignId(Long campaignId) {
        this.campaignId = campaignId;
    }
    
    /**
     * 曝光
     */
    private Long impression;
    public Long getImpression() {
        return impression;
    }
    public void setImpression(Long impression) {
        this.impression = impression;
    }
    
    /**
     * 消耗
     */
    private String cost;
    public String getCost() {
        return cost;
    }
    public void setCost(String cost) {
        this.cost = cost;
    }
    
    /**
     * 点击
     */
    private Long click;
    public Long getClick() {
        return click;
    }
    public void setClick(Long click) {
        this.click = click;
    }
    
    /**
     * 点击成本
     */
    private String ppc;
    public String getPpc() {
        return ppc;
    }
    public void setPpc(String ppc) {
        this.ppc = ppc;
    }
    
    /**
     * 对应时间
     */
    private String bizDate;
    public String getBizDate() {
        return bizDate;
    }
    public void setBizDate(String bizDate) {
        this.bizDate = bizDate;
    }
    
    /**
     * 小时
     */
    private Integer hour;
    public Integer getHour() {
        return hour;
    }
    public void setHour(Integer hour) {
        this.hour = hour;
    }
    
    /**
     * 订单数
     */
    private Long orderNum;
    public Long getOrderNum() {
        return orderNum;
    }
    public void setOrderNum(Long orderNum) {
        this.orderNum = orderNum;
    }
    
    /**
     * 毛gmv
     */
    private String orderGrossGmv1d;
    public String getOrderGrossGmv1d() {
        return orderGrossGmv1d;
    }
    public void setOrderGrossGmv1d(String orderGrossGmv1d) {
        this.orderGrossGmv1d = orderGrossGmv1d;
    }
    
    /**
     * 净gmv
     */
    private String orderNetGmv1d;
    public String getOrderNetGmv1d() {
        return orderNetGmv1d;
    }
    public void setOrderNetGmv1d(String orderNetGmv1d) {
        this.orderNetGmv1d = orderNetGmv1d;
    }
    
    /**
     * 点击率
     */
    private String ctr;
    public String getCtr() {
        return ctr;
    }
    public void setCtr(String ctr) {
        this.ctr = ctr;
    }
    
    /**
     * 转化率
     */
    private String orderConversionRate;
    public String getOrderConversionRate() {
        return orderConversionRate;
    }
    public void setOrderConversionRate(String orderConversionRate) {
        this.orderConversionRate = orderConversionRate;
    }
    
    /**
     * 投入产出比
     */
    private String roi;
    public String getRoi() {
        return roi;
    }
    public void setRoi(String roi) {
        this.roi = roi;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/ad/ChainEffectiveResultDetailWithCampaignAndShopAndDate.java <==
package eleme.openapi.sdk.api.entity.ad;

import eleme.openapi.sdk.api.enumeration.ad.*;
import eleme.openapi.sdk.api.entity.ad.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class ChainEffectiveResultDetailWithCampaignAndShopAndDate{

    /**
     * 店铺id
     */
    private Long shopId;
    public Long getShopId() {
        return shopId;
    }
    public void setShopId(Long shopId) {
        this.shopId = shopId;
    }
    
    /**
     * 计划id
     */
    private Long campaignId;
    public Long getCampaignId() {
        return campaignId;
    }
    public void setCampaignId(Long campaignId) {
        this.campaignId = campaignId;
    }
    
    /**
     * 曝光
     */
    private Long impression;
    public Long getImpression() {
        return impression;
    }
    public void setImpression(Long impression) {
        this.impression = impression;
    }
    
    /**
     * 消耗
     */
    private String cost;
    public String getCost() {
        return cost;
    }
    public void setCost(String cost) {
        this.cost = cost;
    }
    
    /**
     * 点击
     */
    private Long click;
    public Long getClick() {
        return click;
    }
    public void setClick(Long click) {
        this.click = click;
    }
    
    /**
     * 点击成本
     */
    private String ppc;
    public String getPpc() {
        return ppc;
    }
    public void setPpc(String ppc) {
        this.ppc = ppc;
    }
    
    /**
     * 对应时间
     */
    private String bizDate;
    public String getBizDate() {
        return bizDate;
    }
    public void setBizDate(String bizDate) {
        this.bizDate = bizDate;
    }
    
    /**
     * 小时
     */
    private Integer hour;
    public Integer getHour() {
        return hour;
    }
    public void setHour(Integer hour) {
        this.hour = hour;
    }
    
    /**
     * 订单数
     */
    private Long orderNum;
    public Long getOrderNum() {
        return orderNum;
    }
    public void setOrderNum(Long orderNum) {
        this.orderNum = orderNum;
    }
    
    /**
     * 毛gmv
     */
    private String orderGrossGmv1d;
    public String getOrderGrossGmv1d() {
        return orderGrossGmv1d;
    }
    public void setOrderGrossGmv1d(String orderGrossGmv1d) {
        this.orderGrossGmv1d = orderGrossGmv1d;
    }
    
    /**
     * 净gmv
     */
    private String orderNetGmv1d;
    public String getOrderNetGmv1d() {
        return orderNetGmv1d;
    }
    public void setOrderNetGmv1d(String orderNetGmv1d) {
        this.orderNetGmv1d = orderNetGmv1d;
    }
    
    /**
     * 点击率
     */
    private String ctr;
    public String getCtr() {
        return ctr;
    }
    public void setCtr(String ctr) {
        this.ctr = ctr;
    }
    
    /**
     * 转化率
     */
    private String orderConversionRate;
    public String getOrderConversionRate() {
        return orderConversionRate;
    }
    public void setOrderConversionRate(String orderConversionRate) {
        this.orderConversionRate = orderConversionRate;
    }
    
    /**
     * 投入产出比
     */
    private String roi;
    public String getRoi() {
        return roi;
    }
    public void setRoi(String roi) {
        this.roi = roi;
    }
    
}
